@@ -1,13 +1,13 @@
 .onLoad <- function(lib, pkg) {
 # .First.lib <- function(lib, pkg) {
-	library.dynam("CORElearn", pkg, lib)
+	#library.dynam("CORElearn", pkg, lib)
 	initCore(16384) 
 }
 
 .onUnload <- function(libpath) {
 #.Last.lib <- function(libpath) {
 	destroyCore()
-	library.dynam.unload("CORElearn", libpath)
+	#library.dynam.unload("CORElearn", libpath)
 }
 
 initCore <- function(maxModels=16384)
