@@ -481,118 +481,6 @@ void regressionTree::Feature2Str(binnodeReg *Node, char* const Str)
 
 
 
-//************************************************************
-//
-//                        discretizeGreedy
-//                        -----------------
-//
-//     finds best discretization of numeric attribute with
-//      greedy algorithm and returns its estimated quality
-//
-//************************************************************
-double regressionTree::discretizeGreedy(int ContAttrIdx, estimationReg &Estimator, int maxBins, marray<double> &Bounds)
-{
-	Bounds.setFilled(0) ;
-
-	marray<sortRec> sortedAttr(Estimator.TrainSize) ;
-	int i, j, idx ;
-	int OKvalues = 0 ;
-	for (j=0 ; j < Estimator.TrainSize ; j++)
-	{
-		if (isNAcont(NumData(j, ContAttrIdx)))
-			continue ;
-		sortedAttr[OKvalues].key = NumData(j, ContAttrIdx) ;
-		sortedAttr[OKvalues].value = j ;
-		OKvalues ++ ;
-	}
-	if (OKvalues <= 1)    // all the cases have missing value of the attribute or only one OK
-	{
-		// merror("regressionTree::discretizeGreedy", "all values of the attribute are missing or equal") ;
-		return - DBL_MAX ;
-	}
-	sortedAttr.setFilled(OKvalues) ;
-	sortedAttr.qsortAsc() ;
-
-	// eliminate duplicates
-	int unique = 0 ;
-	for (j=1 ; j < OKvalues ; j ++)
-	{
-		if (sortedAttr[j].key != sortedAttr[unique].key)
-		{
-			unique ++ ;
-			sortedAttr[unique] = sortedAttr[j] ;
-		}
-	}
-	OKvalues = unique ;
-	sortedAttr.setFilled(OKvalues) ;
-
-	if (OKvalues <= 1)    // all the cases have missing value of the attribute or only one OK
-	{
-		// merror("regressionTree::discretizeGreedy", "all values of the attribute are missing or equal") ;
-		return - DBL_MAX ;
-	}
-
-
-	int sampleSize ;
-	// we use all the available values only if explicitly demanded
-	if (opt->discretizationSample==0)
-		sampleSize = OKvalues -1;
-	else
-		sampleSize = Mmin(opt->discretizationSample, OKvalues-1) ;
-	marray<int> splits(sampleSize) ;
-	randomizedSample(splits, sampleSize, OKvalues-1) ;
-
-	attributeCount bestType ;
-	double attrValue ;
-
-	Estimator.adjustTables(0, noDiscrete + sampleSize) ;
-	// greedy search
-
-	marray<double> currentBounds(sampleSize) ;
-	int currentIdx ;
-	double bestEstimate = - DBL_MAX, bound ;
-	int currentLimit=0 ; // number of times the current discretization was worse than the best discretization
-	int currentNoValues = 2 ;
-	while (currentLimit <= opt->discretizationLookahead && sampleSize > 0 && (maxBins==0 || currentNoValues <= maxBins))
-	{
-		// compute data columns
-		for (i=0 ; i < Estimator.TrainSize ; i++)
-		{
-			attrValue = Estimator.NumValues(i, ContAttrIdx) ;
-			idx = 0 ;
-			while (idx < currentBounds.filled()  &&  attrValue > currentBounds[idx])
-				idx++ ;
-			idx ++ ; // changes idx to discrete value
-			for (j=0 ; j < sampleSize ; j++)
-			{
-				if (isNAcont(attrValue))
-					Estimator.DiscValues.Set(i, noDiscrete + j, NAdisc) ;
-				else
-					if (attrValue <= sortedAttr[splits[j]].key)
-						Estimator.DiscValues.Set(i, noDiscrete + j, idx) ;
-					else
-						Estimator.DiscValues.Set(i, noDiscrete + j, idx+1) ;
-			}
-		}
-		for (j=0 ; j < sampleSize ; j++)
-			Estimator.prepareDiscAttr(noDiscrete + j, currentNoValues) ;
-		// estimate and select best
-		currentIdx = Estimator.estimate(opt->selectionEstimatorReg, 1, 1, noDiscrete, noDiscrete+sampleSize, bestType) ;
-		bound = (sortedAttr[splits[currentIdx-noDiscrete]].key	+ sortedAttr[splits[currentIdx-noDiscrete]+1].key)/2.0 ;
-		currentBounds.addToAscSorted(bound) ;
-		if (Estimator.DiscEstimation[currentIdx] > bestEstimate)
-		{
-			bestEstimate = Estimator.DiscEstimation[currentIdx] ;
-			Bounds = currentBounds ;
-			currentLimit = 0 ;
-		}
-		else
-			currentLimit ++ ;
-		splits[currentIdx-noDiscrete] = splits[--sampleSize] ;
-		currentNoValues ++ ;
-	}
-	return bestEstimate ;
-}
 
 
 
